#
# spec file for package autotrace
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           autotrace
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pstoedit-devel
Summary:        Program for Converting Bitmaps to Vector Graphics
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Graphics/Convertors
Provides:       bitmap_tracing
Version:        0.31.1
Release:        647.3
Source:         %{name}-%{version}.tar.bz2
Source1:        pstoedit.m4
Patch0:         %{name}-%{version}-quotefix.diff
# PATCH-FIX-OPENSUSE 0001-fix_input_png.patch sfalken@opensuse.org -- fixes build failure against libpng15
Patch1:         0001-fix_input_png.patch
# PATCH-FIX-SECURITY CVE-2019-19004.patch bsc1182158 CVE-2019-19004 -- biWidth*biBitCnt integer overflow fix
Patch2:         CVE-2019-19004.patch
# PATCH-FIX-SECURITY CVE-2019-19005.patch bsc1182159 CVE-2019-19005 CVE-2017-9182, CVE-2017-9190 -- bitmap double free fix
Patch3:         CVE-2019-19005.patch
# PATCH-FIX-SECURITY CVE-2022-32323.patch bsc1201529 -- Heap overflow
Patch4:         CVE-2022-32323.patch
URL:            http://autotrace.sourceforge.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  ImageMagick-devel
# FIXME: Broken with the latest pstoedit. See Fedora patches for partial fix.
#BuildConflicts: pstoedit-devel

%description
AutoTrace is a program for converting bitmaps to vector graphics. The
aim of the AutoTrace project is the development of a freely-available
application similar to CorelTrace or Adobe Streamline. In some aspects,
it is already better. Originally created as a plug-in for the GIMP,
AutoTrace is now a stand-alone program and can be compiled on any UNIX
platform using GCC.

%package -n libautotrace3
Summary:        Library for converting bitmaps to vector graphics
Group:          System/Libraries

%description -n libautotrace3
AutoTrace is a program for converting bitmaps to vector graphics. The
aim of the AutoTrace project is the development of a freely-available
application similar to CorelTrace or Adobe Streamline. In some aspects,
it is already better. Originally created as a plug-in for the GIMP,
AutoTrace is now a stand-alone program and can be compiled on any UNIX
platform using GCC.

%package devel

Summary:        Library for converting bitmaps to vector graphics
Group:          Development/Libraries/C and C++
Requires:       libautotrace3 = %{version}

%description devel
AutoTrace is a program for converting bitmaps to vector graphics. The
aim of the AutoTrace project is the development of a freely-available
application similar to CorelTrace or Adobe Streamline. In some aspects,
it is already better. Originally created as a plug-in for the GIMP,
AutoTrace is now a stand-alone program and can be compiled on any UNIX
platform using GCC.

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fno-tree-sra"
cat %{SOURCE1} >>acinclude.m4
autoreconf -f -i
%configure\
	--disable-static
%{__make} %{?jobs:-j%jobs}

%install
%make_install
%{__rm} -f %{buildroot}%{_libdir}/*.la

%post -n libautotrace3 -p /sbin/ldconfig

%postun -n libautotrace3 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc AUTHORS COPYING FAQ NEWS README README.MING THANKS TODO
%{_bindir}/autotrace
%{_mandir}/man1/autotrace.1*

%files -n libautotrace3
%defattr(-, root, root)
%doc COPYING.LIB
%{_libdir}/*.so.*

%files devel
%defattr(-, root, root)
%{_bindir}/*-config
%{_datadir}/aclocal/*.m4
%{_includedir}/autotrace
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov  8 2022 Jason Sikes <jsikes@suse.com>
- Added CVE-2022-32323.patch
  * [bsc#1201529, CVE-2022-32323]
  * Fixes Heap overflow in ReadImage()
* Fri May 13 2022 Stanislav Brabec <sbrabec@suse.com>
- biWidth*biBitCnt integer overflow fix (bsc#1182158,
  CVE-2019-19004, CVE-2019-19004.patch).
- Bitmap double free fix (bsc1182159, CVE-2019-19005,
  CVE-2017-9182, CVE-2017-9190, CVE-2019-19005.patch).
* Tue Aug 12 2014 sfalken@opensuse.org
- Add 0001-fix_input_png.patch:  Corrects build failure against libpng15
- Updated .spec file to use %%make_install macro
* Thu Feb 28 2013 coolo@suse.com
- update license to new format
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Mar  7 2011 sbrabec@suse.cz
- Split according to shared library packaging rules.
- Enabled ImageMagick support.
* Mon Dec 20 2010 meissner@suse.de
- libexif does not seem to be directly required
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- cleanup spec file a bit
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  6 2005 sbrabec@suse.cz
- Provide bitmap_tracing virtual.
* Tue Dec  7 2004 pth@suse.de
- Fix AC_DEFUN quoting
* Mon Jun 28 2004 ro@suse.de
- added libjpeg,libtiff to neededforbuild
* Sun Apr 25 2004 ro@suse.de
- added no-strict-aliasing
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Jul 28 2003 meissner@suse.de
- added libexif to nfb
* Mon May 26 2003 ro@suse.de
- add manpage to filelist
* Sat May 10 2003 schwab@suse.de
- Force libtool update.
* Thu Dec 26 2002 ro@suse.de
- added liblcms-devel to neededforbuild
* Thu Nov 21 2002 sbrabec@suse.cz
- Added new package.
- Libtool updates, otherwise cannot create shared   library (autoreconf
  needs extra macro in pstoedit.m4).
